==> MMDX-v1.30a-src.zip: MMDX-v1.30a-src/MikuMikuDanceXNA/Model/ModelData/MMDModelData.cs <==
using System.Collections.Generic;
using XNAModel = Microsoft.Xna.Framework.Graphics.Model;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;

namespace MikuMikuDance.XNA.Model.ModelData
{
    /// <summary>
    /// MMDff[^NX(p)
    /// </summary>
    public class MMDModelData//̃NX͎Qƌ^ɂBȂȂ炱̃NX̎󂯓n
    {
        /// <summary>
        /// ff[^
        /// </summary>
        public XNAModel ModelData;
        /// <summary>
        /// MMDp̃{[
        /// </summary>
        public MMDBoneData[] Bones;
        /// <summary>
        /// MMDp̕\
        /// </summary>
        public MMDSkinData[] Skins;
        /// <summary>
        /// \p̒_
        /// </summary>
        public int NumVertexForFace;
        /// <summary>
        /// MMDp̍̏
        /// </summary>
        public MMDRigid[] Rigids;
        /// <summary>
        /// MMDp̃WCg
        /// </summary>
        public MMDJoint[] Joints;
        /// <summary>
        /// VF[_ɓn\_
        /// </summary>
        public Vector4[] FaceData;
        /// <summary>
        /// VF[_ɕ\_nۂɎgp钸_eNX`TCYX
        /// </summary>
        public int FaceDataTextureSizeX;
        /// <summary>
        /// VF[_ɓnۂɎgp钸_eNX`TCYY
        /// </summary>
        public int FaceDataTextureSizeY;
        /// <summary>
        /// VF[_ɕ\_ʒunۂɎgp钸_eNX`TCYX
        /// </summary>
        public int FaceVertTextureSizeX;
        /// <summary>
        /// VF[_ɕ\_ʒunۂɎgp钸_eNX`TCYY
        /// </summary>
        public int FaceVertTextureSizeY;
    }
}

==> MMDX-v1.41a-src.zip: MMDX-v1.41a-src/MikuMikuDanceXNA/Model/ModelData/MMDModelData.cs <==
using System.Collections.Generic;
using XNAModel = Microsoft.Xna.Framework.Graphics.Model;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;

namespace MikuMikuDance.XNA.Model.ModelData
{
    /// <summary>
    /// MMDff[^NX(p)
    /// </summary>
    public class MMDModelData//̃NX͎Qƌ^ɂBȂȂ炱̃NX̎󂯓n
    {
        /// <summary>
        /// ff[^
        /// </summary>
        public XNAModel ModelData;
        /// <summary>
        /// MMDp̃{[
        /// </summary>
        public MMDBoneData[] Bones;
        /// <summary>
        /// MMDp̕\
        /// </summary>
        public MMDSkinData[] Skins;
        /// <summary>
        /// \p̒_
        /// </summary>
        public int NumVertexForFace;
        /// <summary>
        /// MMDp̍̏
        /// </summary>
        public MMDRigid[] Rigids;
        /// <summary>
        /// MMDp̃WCg
        /// </summary>
        public MMDJoint[] Joints;
        /// <summary>
        /// VF[_ɓn\_
        /// </summary>
        public Vector4[] FaceData;
        /// <summary>
        /// VF[_ɕ\_nۂɎgp钸_eNX`TCYX
        /// </summary>
        public int FaceDataTextureSizeX;
        /// <summary>
        /// VF[_ɓnۂɎgp钸_eNX`TCYY
        /// </summary>
        public int FaceDataTextureSizeY;
        /// <summary>
        /// VF[_ɕ\_ʒunۂɎgp钸_eNX`TCYX
        /// </summary>
        public int FaceVertTextureSizeX;
        /// <summary>
        /// VF[_ɕ\_ʒunۂɎgp钸_eNX`TCYY
        /// </summary>
        public int FaceVertTextureSizeY;
        /// <summary>
        /// p[c̒SXg
        /// </summary>
        public PartCenter[] PartCenters;
        /// <summary>
        /// p[c̒SgpZ\[gsǂ
        /// </summary>
        public bool UsePartCenterZSort;
        internal void CalcDrawOrder(Matrix World, Matrix View, PartCenterCompare ZCompare)
        {
            Matrix WorldView;
            Matrix.Multiply(ref World, ref View, out WorldView);
            foreach (var partcenter in PartCenters)
                partcenter.Calc(ref WorldView);
        }
    }
}
